@@ -536,7 +536,7 @@ muse_autocalib_slice_median(muse_pixtable *aPixtable, double aClip,
           slice_flux[slidx] = NAN;
         }
         if (debug) {
-          cpl_msg_debug(__func__, "  - SLICE %02hu : %f (%d)",
+          cpl_msg_debug(__func__, "  - SLICE %02d : %f (%d)",
                         s+1, slice_flux[slidx], npts[k]);
         }
       } /* for s */
@@ -660,7 +660,7 @@ muse_autocalib_slice_median(muse_pixtable *aPixtable, double aClip,
           corr[k] = tot_flux / slice_flux[slidx];
         }
         if (debug) {
-          cpl_msg_debug(__func__, "  - SLICE %02hu : %f", s+1, corr[k]);
+          cpl_msg_debug(__func__, "  - SLICE %02d : %f", s+1, corr[k]);
         }
       } /* for s */
       if ((slice_count1 + slice_count2) == 0) {
@@ -715,7 +715,7 @@ muse_autocalib_slice_median(muse_pixtable *aPixtable, double aClip,
           oldcorr = corr[k];
           corr[k] = tot_flux / refflux;
           if (debug) {
-            cpl_msg_debug(__func__, "  - SLICE %02hu : %f -> Using IFU Mean : "
+            cpl_msg_debug(__func__, "  - SLICE %02d : %f -> Using IFU Mean : "
                           "%f", s+1, oldcorr, corr[k]);
           }
         }
