@@ -810,14 +810,18 @@ muse_datacube_save(muse_datacube *aCube, const char *aFilename)
       if (!strncmp(bunit, kMuseFluxUnitString,
                    strlen(kMuseFluxUnitString) + 1)) {
         /* standard unit syntax */
-        bunitStat = kMuseFluxStatString;
+        bunitStat = cpl_strdup(kMuseFluxStatString);
       } else if (!strncmp(bunit, kMuseIdpFluxDataUnit,
                           strlen(kMuseIdpFluxDataUnit) + 1)) {
         /* IDP unit syntax */
-        bunitStat = kMuseIdpFluxStatUnit;
+        bunitStat = cpl_strdup(kMuseIdpFluxStatUnit);
+      } else if (strlen(bunit) > 0) {
+        /* For other, not flux calibrated data use squared data unit string */
+        bunitStat = cpl_sprintf("(%s)**2", bunit);
       }
       if (bunitStat) {
         cpl_propertylist_append_string(header, "BUNIT", bunitStat);
+        cpl_free((char *)bunitStat);
       }
     }
     muse_utils_copy_modified_header(aCube->header, header, "OBJECT",
