@@ -30,6 +30,7 @@
 #include "muse_cplwrappers.h"
 #include "muse_image.h"
 #include "muse_imagelist.h"
+#include "muse_table.h"
 
 /** @addtogroup muse_resampling */
 /**@{*/
@@ -156,7 +157,7 @@ cpl_error_code muse_datacube_save(muse_datacube *, const char *);
 cpl_error_code muse_datacube_save_recimages(const char *, muse_imagelist *, cpl_array *);
 void muse_datacube_delete(muse_datacube *);
 
-muse_image *muse_euro3dcube_collapse(muse_euro3dcube *, cpl_table *);
-muse_image *muse_datacube_collapse(muse_datacube *, cpl_table *);
+muse_image *muse_euro3dcube_collapse(muse_euro3dcube *, const muse_table *);
+muse_image *muse_datacube_collapse(muse_datacube *, const muse_table *);
 
 #endif /* MUSE_DATACUBE_H */
