@@ -97,9 +97,8 @@
 #define MUSE_TAG_SOURCE_LIST      "SOURCE_LIST"
 /* tags used by the muse_qi_mask recipe */
 #define MUSE_TAG_MASK_IMAGE  "MASK_IMAGE"
-/* tags from detmon used by the muse_lingain recipe */
-#define MUSE_TAG_LINEARITY_BIAS "DETMON_LAMP_OFF"
-#define MUSE_TAG_LINEARITY_FLAT "DETMON_LAMP_ON"
+#define MUSE_TAG_LINEARITY_BIAS "LINGAIN_LAMP_OFF"
+#define MUSE_TAG_LINEARITY_FLAT "LINGAIN_LAMP_ON"
 
 /* Reasons to exclude frames from a framelist */
 #define MUSE_EXCLUDE_OK           0 /* frame not excluded */
@@ -162,13 +161,13 @@
 #define MUSE_HDR_FLAT_FLUX_SKY  "ESO DRS MUSE FLAT FLUX SKY"
 
 /* FITS header keywords to store the applied RA/DEC offsets */
-#define MUSE_HDR_OFFSETi_DATEOBS   "ESO DRS MUSE OFFSET%d DATE-OBS"
-#define MUSE_HDR_OFFSETi_DATEOBS_C "offset %d applied to exposure with this DATE-OBS"
-#define MUSE_HDR_OFFSETi_DRA       "ESO DRS MUSE OFFSET%d DRA"
+#define MUSE_HDR_OFFSETi_DATEOBS   "ESO DRS MUSE OFFSET%u DATE-OBS"
+#define MUSE_HDR_OFFSETi_DATEOBS_C "offset %u applied to exposure with this DATE-OBS"
+#define MUSE_HDR_OFFSETi_DRA       "ESO DRS MUSE OFFSET%u DRA"
 #define MUSE_HDR_OFFSETi_DRA_C     "[deg] (= %f arcsec) RA offset applied"
-#define MUSE_HDR_OFFSETi_DDEC      "ESO DRS MUSE OFFSET%d DDEC"
+#define MUSE_HDR_OFFSETi_DDEC      "ESO DRS MUSE OFFSET%u DDEC"
 #define MUSE_HDR_OFFSETi_DDEC_C    "[deg] (= %f arcsec) DEC offset applied"
-#define MUSE_HDR_FLUX_SCALEi       "ESO DRS MUSE FLUX SCALE%d"
+#define MUSE_HDR_FLUX_SCALEi       "ESO DRS MUSE FLUX SCALE%u"
 #define MUSE_HDR_FLUX_SCALEi_C     "flux scale factor applied"
 
 /* FITS header keyword to list the filter name and *
@@ -274,9 +273,9 @@
 
 /* Geometry QC headers */
 #define QC_GEO_PREFIX       "ESO QC GEO "
-#define QC_GEO_EXPk_MEAN    QC_GEO_PREFIX"EXP%d FWHM MEAN"
-#define QC_GEO_EXPk_MEDIAN  QC_GEO_PREFIX"EXP%d FWHM MEDIAN"
-#define QC_GEO_EXPk_STDEV   QC_GEO_PREFIX"EXP%d FWHM STDEV"
+#define QC_GEO_EXPk_MEAN    QC_GEO_PREFIX"EXP%u FWHM MEAN"
+#define QC_GEO_EXPk_MEDIAN  QC_GEO_PREFIX"EXP%u FWHM MEDIAN"
+#define QC_GEO_EXPk_STDEV   QC_GEO_PREFIX"EXP%u FWHM STDEV"
 #define QC_GEO_FWHM_MEAN    QC_GEO_PREFIX"FWHM MEAN"
 #define QC_GEO_FWHM_STDEV   QC_GEO_PREFIX"FWHM STDEV"
 #define QC_GEO_IFUi_ANGLE   QC_GEO_PREFIX"IFU%hhu ANGLE"
@@ -366,8 +365,16 @@
 #define QC_ASTROMETRY_RESY   "ESO QC ASTRO MEDRES Y"
 
 /* Non-linearity gain QC headers */
-#define QC_LINGAIN_PREFIX     "ESO QC LINGAIN "
-#define QC_LINGAIN_GFITi_RMS  QC_LINGAIN_PREFIX "GFIT%u RMS"
+#define QC_LINGAIN_PREFIX      "ESO QC LINGAIN "
+#define QC_LINGAIN_RONi        QC_LINGAIN_PREFIX "OUT%u RON"
+#define QC_LINGAIN_RONi_ERR    QC_LINGAIN_PREFIX "OUT%u RONERR"
+#define QC_LINGAIN_RONi_MEDIAN QC_LINGAIN_PREFIX "OUT%u RON MEDIAN"
+#define QC_LINGAIN_RONi_MAD    QC_LINGAIN_PREFIX "OUT%u RON MAD"
+#define QC_LINGAIN_CONADi      QC_LINGAIN_PREFIX "OUT%u CONAD"
+#define QC_LINGAIN_GAINi       QC_LINGAIN_PREFIX "OUT%u GAIN"
+#define QC_LINGAIN_GAINi_ERR   QC_LINGAIN_PREFIX "OUT%u GAINERR"
+#define QC_LINGAIN_COUNTSi_MIN QC_LINGAIN_PREFIX "OUT%u COUNTS MIN"
+#define QC_LINGAIN_COUNTSi_MAX QC_LINGAIN_PREFIX "OUT%u COUNTS MAX"
 #define QC_LINGAIN_NLFITi_RMS QC_LINGAIN_PREFIX "NLFIT%u RMS"
 
 #endif /* MUSE_DFS_H */
