@@ -39,6 +39,9 @@
 #include "muse_flux.h"
 #include "muse_utils.h"
 
+//HDRL - needed for hdrl_maglim_compute()
+#include "hdrl_maglim.h"
+
 /*----------------------------------------------------------------------------*
  *                              Defines                                       *
  *----------------------------------------------------------------------------*/
@@ -545,26 +548,20 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
 
   /* Get median pixel value ignoring bad pixel values (NaN) */
   cpl_image_reject_value(fov->data, CPL_VALUE_NOTFINITE);
-#undef USE_HISTOGRAM
-#ifndef USE_HISTOGRAM
-  double median = cpl_image_get_median(fov->data);
-#else
-  double sigma = 0;
-  double median = cpl_image_get_mad(fov->data, &sigma);
-#endif
 
-
-  /* Create cleaned FOV image from the original image using only       *
-   * pixels which have less intensity than the median. All invalid     *
-   * pixels are recorded in a mask image. To prepare for the following *
-   * convolution step the image is also cropped to an even number of   *
-   * pixels along both axes (if needed).                               */
-  cpl_size _nx = (nx % 2) == 0 ? nx : nx - 1;
-  cpl_size _ny = (ny % 2) == 0 ? ny : ny - 1;
+  /* Create cleaned FOV image from the original image. 
+   * Only pixels with less intensity than the *mode* are considered by     *
+   * hdrl_maglim_compute. All invalid pixels are recorded in a mask img.   * 
+   * image. Image convolution is now also handled by hdrl_maglim_compute.  */
+   //* Image size is also cropped along both axes (if needed).               
+   //Not sure why we trim the image here - is it really needed?
+  cpl_size _nx = nx;//(nx % 2) == 0 ? nx : nx - 1;
+  cpl_size _ny = ny;//(ny % 2) == 0 ? ny : ny - 1;
   cpl_size npixel = _nx * _ny;
 
   cpl_image *fov_clean = cpl_image_new(_nx, _ny, CPL_TYPE_DOUBLE);
-  cpl_image_fill_window(fov_clean, 1, 1, _nx, _ny, median);
+  cpl_image_fill_window(fov_clean, 1, 1, _nx, _ny, NAN);
+  //cpl_image_fill_window(fov_clean, 1, 1, _nx, _ny, median);
 
   cpl_mask *fov_invalid  = cpl_mask_new(_nx, _ny);
   cpl_binary *_fov_invalid = cpl_mask_get_data(fov_invalid);
@@ -573,12 +570,13 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
   double *_fov_clean = cpl_image_get_data_double(fov_clean);
 
   cpl_size iy;
+  cpl_size ix;
   for (iy = 0; iy < _ny; ++iy) {
-    cpl_size ix;
     for (ix = 0; ix < _nx; ++ix) {
       cpl_size _ipixel = nx * iy + ix;
-      if ((isnan(_fov_data[_ipixel]) == 0) &&
-          (_fov_data[_ipixel] < median)) {
+      if ((isnan(_fov_data[_ipixel]) == 0) //&&
+          //(_fov_data[_ipixel] < median)
+          ) {
         _fov_clean[_nx * iy + ix] = _fov_data[_ipixel];
       } else {
         _fov_invalid[_nx * iy + ix] = CPL_BINARY_1;
@@ -586,6 +584,8 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
 
     }
   }
+
+
   muse_image_delete(fov);
 
   /* Convolve the valid image with a Gaussian normalized to 1 at the peak.  *
@@ -593,22 +593,28 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
    * the integral (the total sum of the elements) is 1. Thus it has to be   *
    * renormalized. The half width (radius) of the convolution box is set to *
    * 3 sigma.                                                             */
-  const double csigma = aFwhm / (2. * sqrt(2. * log(2.)));
+  /*const double csigma = aFwhm / (2. * sqrt(2. * log(2.)));
   const double radius = CPL_MAX(3. * csigma, 2.001);
   const int nhalf = (int)(radius + 0.5);
-  cpl_matrix *ckernel = muse_matrix_new_gaussian_2d(nhalf, nhalf, csigma);
+  */
+/*  //This isn't needed as convolution now done inside hdrl_maglim_compute
+ *  cpl_matrix *ckernel = muse_matrix_new_gaussian_2d(nhalf, nhalf, csigma);
   cpl_matrix_divide_scalar(ckernel, cpl_matrix_get_max(ckernel));
 
   cpl_image *fov_smooth = muse_convolve_image(fov_clean, ckernel);
 
   cpl_matrix_delete(ckernel);
-  cpl_image_delete(fov_clean);
+  */
+  //cpl_image_delete(fov_clean);
 
   /* Perform a morphological dilation on the mask to create an additional  *
    * border of masked pixels around the already masked areas. This should  *
    * invalidated pixels in the smoothed image which are affected by border *
    * effects during the convolution.                                       */
 
+  /*Not sure this is needed - isn't this handled by the convolution_boundary
+   * aspects in hdrl_maglim_compute i.e. HDRL_IMAGE_EXTEND_MIRROR*/
+  /* 
   cpl_size nmask = 2 * nhalf + 1;
   cpl_mask *mkernel = cpl_mask_new(nmask, nmask);
   cpl_binary *_mkernel = cpl_mask_get_data(mkernel);
@@ -623,16 +629,20 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
           CPL_BINARY_0 : CPL_BINARY_1;
     }
   }
+  */
 
-  cpl_mask *fov_mask = cpl_mask_new(_nx, _ny);
+  /*cpl_mask *fov_mask = cpl_mask_new(_nx, _ny);
   cpl_mask_filter(fov_mask, fov_invalid, mkernel,
                   CPL_FILTER_DILATION, CPL_BORDER_ZERO);
   cpl_mask_delete(mkernel);
+  */
 
   /* The filtering of the mask leaves an nhalf pixel wide border on each   *
    * side of the mask image which are not flagged. These are set as masked *
    * here.                                                                 *
    */
+  /*Ditto here - if the dilation is not performed, we don't need this?*/
+  /*
   cpl_binary *_fov_mask = cpl_mask_get_data(fov_mask);
 
   cpl_size ipixel;
@@ -644,11 +654,12 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
       _fov_mask[_y * _nx + _x] = CPL_BINARY_1;
     }
   }
-
-  /* Check whether enough valid pixels are left for the following analysis. *
+*/
+  /* Is this really necessary?
+   * Check whether enough valid pixels are left for the following analysis. *
    * If not enough valid pixels are found revert the dilated mask to the    *
    * original and use this instead.                                         */
-  if (npixel - cpl_mask_count(fov_mask) < min_valid) {
+/*  if (npixel - cpl_mask_count(fov_mask) < min_valid) {
     cpl_msg_debug(__func__, "Number of valid pixels in the dilated mask is"
                   "less than 2! Falling back to the original mask!");
     cpl_mask_delete(fov_mask);
@@ -657,114 +668,45 @@ muse_idp_compute_abmaglimit(const muse_datacube *aCube, double aWlenMin,
   } else {
     cpl_mask_delete(fov_invalid);
   }
-
-#ifndef USE_HISTOGRAM
-  const double *_fov_smooth = cpl_image_get_data_double_const(fov_smooth);
-
-  double *_fov_valid = cpl_calloc(npixel, sizeof *_fov_valid);
-
-  cpl_size nvalid = 0;
-  for (ipixel = 0; ipixel < npixel; ++ipixel) {
-    if (_fov_mask[ipixel] == CPL_BINARY_0) {
-      _fov_valid[nvalid] = _fov_smooth[ipixel];
-      ++nvalid;
-    }
-  }
-  cpl_mask_delete(fov_mask);
-  cpl_image_delete(fov_smooth);
-
-  cpl_vector *fov_valid = cpl_vector_wrap(nvalid, _fov_valid);
-  double sdev = cpl_vector_get_stdev(fov_valid);
-
-  cpl_vector_unwrap(fov_valid);
-  cpl_free(_fov_valid);
-
-  /* Compute the AB limiting magnitude: Numerical values are from     *
-   * converting f(nu) to f(lambda) and from the unit conversion [Jy]  *
-   * to [erg/cm**2/s/Angstrom]:                                       *
-   *    f(nu) = lambda**2 / c * f(lambda),                            *
-   *    f(nu)/Jy = 3.34e4 * (lambda/Angstrom)**2 *                    *
-   *               f(lambda)/(erg/cm**2/s/Angstrom)                   *
-   * and the monochromatic AB magnitude                               *
-   *    m_AB = -2.5 * log10(f(nu) / (3631 Jy))                        */
-
-  double zeropoint  = -2.5 * log10(5. * (3.34e4 * aWlenMin * aWlenMax / 3631.));
-  double abmaglimit = -2.5 * log10(2. * sdev / kMuseFluxUnitFactor) + zeropoint;
-#else
-  /* Create histogram from the smoothed image of valid pixels. The bin size *
-   * is chosen to be 0.1 times the median absolute deviation of the pixel   *
-   * values of the original image                                           */
-  const double hstep = 0.1 * sigma;
-  double hmin  = cpl_image_get_min(fov_smooth);
-  double hmax  = cpl_image_get_max(fov_smooth);
-
-  cpl_size nbins = (hmax - hmin) / hstep + 1;
-  cpl_vector *bins = cpl_vector_new(nbins);
-
-  /* To prepare for the following fit of the histogram peak use the bin *
-   * center as the value of the histogram bin                           */
-  cpl_size ibin;
-  for (ibin = 0; ibin < nbins; ++ ibin) {
-    cpl_vector_set(bins, ibin, hmin + (ibin + 0.5) * hstep);
+*/
+  //mask the data..
+  if(fov_invalid){
+    cpl_image_reject_from_mask(fov_clean,fov_invalid);
+    cpl_mask_delete(fov_invalid);
   }
 
-  cpl_vector *histogram = cpl_vector_new(nbins);
-  cpl_vector_fill(histogram, 0.);
-  double *hdata = cpl_vector_get_data(histogram);
-
-  const double *_fov_smooth = cpl_image_get_data_double_const(fov_smooth);
-
-  for (ipixel = 0; ipixel < npixel; ++ipixel) {
-    if ((_fov_mask[ipixel] == CPL_BINARY_0) &&
-        (_fov_smooth[ipixel] >= hmin) && (_fov_smooth[ipixel] <= hmax)) {
-      cpl_size jbin = (cpl_size)((_fov_smooth[ipixel] + fabs(hmin)) / hstep);
-      hdata[jbin] += 1.;
-    }
-  }
-
-  cpl_mask_delete(fov_mask);
-  cpl_image_delete(fov_smooth);
-
-  /* Fit a Gaussian to the histogram peak */
-  double center  = 0.;
-  double sdev    = 0.;
-  double area    = 0.;
-  double bckgrnd = 0.;
-
-  cpl_fit_mode mode = CPL_FIT_CENTROID | CPL_FIT_STDEV | CPL_FIT_AREA;
-  cpl_errorstate status = cpl_errorstate_get();
-  cpl_error_code ecode  = cpl_vector_fit_gaussian(bins, NULL, histogram, NULL,
-                                                  mode,
-                                                  &center, &sdev, &area, &bckgrnd,
-                                                  NULL, NULL, NULL);
-  cpl_vector_delete(histogram);
-  cpl_vector_delete(bins);
-
+  //Changes introduced by PIPE-9759 
+  double zeropoint = -2.5*log10(3.34*pow(10.,4.)*(aWlenMin*aWlenMax) /3631.)-2.5*log10(pow(10.,-20));
+  cpl_msg_info(cpl_func,"Calculated zeropoint: %.4f",zeropoint);
+  double fwhm = aFwhm;
+  cpl_size kx = (int)fwhm*2.0+1.0;
+  cpl_size ky = (int)fwhm*2.0+1.0;
+  //which method do we use?
+  hdrl_image_extend_method convolution_boundary = HDRL_IMAGE_EXTEND_MIRROR;
+  //hdrl_image_extend_method convolution_boundary = HDRL_IMAGE_EXTEND_NEAREST;
   double abmaglimit = 0.;
-  if (!cpl_errorstate_is_equal(status) && (ecode != CPL_ERROR_CONTINUE)) {
-    cpl_msg_debug(__func__, "Fit of a Gaussian to the histogram peak failed!");
-    cpl_errorstate_set(status);
-  } else {
-    if (ecode == CPL_ERROR_CONTINUE) {
-      cpl_msg_debug(__func__, "Fit of a Gaussian to the histogram peak did "
-                    "not converge!");
-      cpl_errorstate_set(status);
-    }
 
-    /* Compute the AB limiting magnitude: Numerical values are from     *
-     * converting f(nu) to f(lambda) and from the unit conversion [Jy]  *
-     * to [erg/cm**2/s/Angstrom]:                                       *
-     *    f(nu) = lambda**2 / c * f(lambda),                            *
-     *    f(nu)/Jy = 3.34e4 * (lambda/Angstrom)**2 *                    *
-     *               f(lambda)/(erg/cm**2/s/Angstrom)                   *
-     * and the monochromatic AB magnitude                               *
-     *    m_AB = -2.5 * log10(f(nu) / (3631 Jy))                        */
+  double histo_min = 0.;
+  double histo_max = 0.; /* min > max -> autoset by algorithm */
+  double bin_size = 0.; /* bin_size <= 0 -> autoset by algorithm */ 
+  cpl_size error_niter = 0; /* analytic error */
+  hdrl_mode_type mode_method = HDRL_MODE_MEDIAN; /* very robust */
+  mode_method = HDRL_MODE_WEIGHTED;
 
-    double zeropoint  = -2.5 *
-        log10(5. * (3.34e4 * aWlenMin * aWlenMax / 3631.));
-    abmaglimit = -2.5 * log10(2. * sdev / kMuseFluxUnitFactor) + zeropoint;
+  cpl_error_code err;
+  err  = cpl_image_save(fov_clean,"fov_clean.fits",CPL_TYPE_DOUBLE,NULL,CPL_IO_CREATE);
+  
+  hdrl_parameter * mode_parameter = NULL; 
+  //the parameters for hdrl_collapse_mode_parameter_create set algorithm to autoset the values...
+  mode_parameter = hdrl_collapse_mode_parameter_create(histo_min, histo_max, bin_size, mode_method, error_niter);
+  err = hdrl_maglim_compute(fov_clean,zeropoint,fwhm,kx,ky,convolution_boundary,mode_parameter,&abmaglimit);
+  if(err){
+    abmaglimit = -99.0;
+    cpl_msg_info(cpl_func,"Failed to calculate limiting magnitude: %s",cpl_error_get_message());
   }
-#endif
+  cpl_msg_info(cpl_func,"Calculated limiting magnitude of %.4f (%s)",abmaglimit,cpl_error_get_message()); 
+  hdrl_parameter_delete(mode_parameter);
+  cpl_image_delete(fov_clean);
 
   return abmaglimit;
 }
