@@ -45,12 +45,7 @@
 #include "muse_tracing.h"
 #include "muse_utils.h"
 
-/*----------------------------------------------------------------------------*/
-/**
-   @defgroup muse_lsf       Line Spread Function related functions
- */
-/*----------------------------------------------------------------------------*/
-
+/** @addtogroup muse_lsf */
 /**@{*/
 
 /*----------------------------------------------------------------------------*/
