@@ -328,11 +328,11 @@ muse_phys_air_to_vacuum(muse_pixtable *aPixtable, unsigned int aFlags)
   /* compute refractive index for reference wavelength in um and *
    * output properties in "natural" (for the formulae) units     */
   double d1, d2,
-         fp, /* water vapor pressure in mmHg */
+         fp = 0., /* water vapor pressure in mmHg */
          p = pres * 100, /* atmopheric pressure [Pa] */
          t = temp - 273.15, /* temperature [Celsius] */
-         pv, /* partial vapor pressure */
-         xv; /* mole fraction */
+         pv = 0., /* partial vapor pressure */
+         xv = 0.; /* mole fraction */
   if (method == MUSE_PHYS_METHOD_OWENS) {
     muse_phys_nrindex_owens_coeffs(temp, rhum, pres, &d1, &d2);
     cpl_msg_info(__func__, "Air to vacuum conversion for T=%.2f K, RH=%.2f %%, "
