@@ -348,13 +348,20 @@ muse_pixgrid_create(muse_pixtable *aPixtable, cpl_propertylist *aHeader,
   muse_pixgrid *grid = muse_pixgrid_new(aXSize, aYSize, aZSize, nth);
 
   /* parallel region to fill the pixel grid */
+
+  // FIXME: Removed default(none) clause here, to make the code work with
+  //        gcc9 while keeping older versions of gcc working too without
+  //        resorting to conditional compilation. Having default(none) here
+  //        causes gcc9 to abort the build because of __func__ not being
+  //        specified in a data sharing clause. Adding a data sharing clause
+  //        makes older gcc versions choke.
 #ifdef ESO_ENABLE_DEBUG
-  #pragma omp parallel num_threads(nth) default(none)    /* as req. by Ralf */ \
+  #pragma omp parallel num_threads(nth)                                        \
           shared(aXSize, aYSize, aZSize, az1, az2, cd33, crpix3, crval3, debug,\
                  grid, lbda, loglambda, nsel, ptxoff, ptyoff, sel,             \
                  showprogress, timeinit, timeprogress, wcs, xpos, ypos)
 #else
-  #pragma omp parallel num_threads(nth) default(none)    /* as req. by Ralf */ \
+  #pragma omp parallel num_threads(nth)                                        \
           shared(aXSize, aYSize, aZSize, az1, az2, cd33, crpix3, crval3, grid, \
                  lbda, loglambda, nsel, ptxoff, ptyoff, sel, showprogress,     \
                  timeinit, timeprogress, wcs, xpos, ypos)
