@@ -114,12 +114,13 @@ typedef struct {
   muse_mask *sky_mask; /**< The sky mask */
   muse_sky_params skymodel_params; /**< Parameters for the sky model fit */
   muse_autocalib_type autocalib; /**< Type of autocalibration to run, if any */
+  muse_table *autocal_table; /**< User table with autocalibration factors */
   cpl_frame *refframe; /**< reference frame (flux response reference *
                         *   or astrometry position reference)        */
   cpl_table *tellregions; /**< telluric regions table */
   muse_flux_profile_type profile; /**< the profile to use for flux integration */
   muse_flux_selection_type select; /**< how to select the standard star */
-  muse_flux_smooth_type smooth; /**< how to smooth the output response curve */
+  muse_spectrum_smooth_type smooth; /**< how to smooth the output response curve */
   double detsigma; /**< the detection sigma for the astrometric field */
   double radius; /**< initial radius in pixels for pattern matching *
                   *   identification in the astrometric field       */
