@@ -94,7 +94,7 @@ muse_raman_lines_load(muse_processing *aProcessing)
 
 /*----------------------------------------------------------------------------*/
 /**
-   @brief  Add a Raman line profile to pixtable
+   @brief  Add a Raman line profile to pixel table.
    @param  aPixtable   table with wavelengths and an lsf column
    @param  aRamanLines Raman line list
    @param  aGroup      line group to take from the Raman line list
@@ -102,7 +102,7 @@ muse_raman_lines_load(muse_processing *aProcessing)
    @param  aLsfCube    LSF data cube
 
    This will, slice by slice, add the raman lines profile to all
-   entries in the pixtable. The pixtable is required to hold an "lsf"
+   entries in the pixel table. The pixel table is required to hold an "lsf"
    column with values set to zero. Subsequent calls of this function
    add the line spread functions of each call.
 */
@@ -116,7 +116,14 @@ muse_raman_add_lsf(muse_pixtable *aPixtable, cpl_table *aRamanLines,
   cpl_size n_slices = muse_pixtable_extracted_get_size(slice_pixtable);
   cpl_size i_slice;
   cpl_error_code rc[n_slices];
-  #pragma omp parallel for default(none)                                       \
+
+  // FIXME: Removed default(none) clause here, to make the code work with
+  //        gcc9 while keeping older versions of gcc working too without
+  //        resorting to conditional compilation. Having default(none) here
+  //        causes gcc9 to abort the build because of __func__ not being
+  //        specified in a data sharing clause. Adding a data sharing clause
+  //        makes older gcc versions choke.
+  #pragma omp parallel for                                                     \
           shared(aLsfCube, aRamanLines, aGroup, aFlux, n_slices,               \
                  slice_pixtable, rc)
   for (i_slice = 0; i_slice < n_slices; i_slice++) {
@@ -137,7 +144,7 @@ muse_raman_add_lsf(muse_pixtable *aPixtable, cpl_table *aRamanLines,
     int n_lines = cpl_table_get_nrow(aRamanLines);
     rc[i_slice] = CPL_ERROR_NONE;
     for (i_line = 0; i_line < n_lines; i_line++) {
-      if (cpl_table_get(aRamanLines, "group", i_line, NULL) != aGroup) {
+      if (cpl_table_get_int(aRamanLines, "group", i_line, NULL) != aGroup) {
         continue;
       }
       double wavelength = cpl_table_get(aRamanLines, "lambda", i_line, NULL);
@@ -169,7 +176,7 @@ muse_raman_add_lsf(muse_pixtable *aPixtable, cpl_table *aRamanLines,
    @return Array with fit values
 
    The fit uses a common spatial profile (two dimensional 2nd order
-   polynomial) for both pixtables. The spatial profile is returned in
+   polynomial) for both pixel tables. The spatial profile is returned in
    the first five values of the returned array:
 
     * 0 - x² coefficient
@@ -180,7 +187,7 @@ muse_raman_add_lsf(muse_pixtable *aPixtable, cpl_table *aRamanLines,
 
    The flux is normalized to be 1 at the center (x=y=0).
 
-   This requires the pixtables to have an additional "lsf" column
+   This requires the pixel tables to have an additional "lsf" column
    containing the Line profile of the Raman scattering, normalized to
    one.
  */
@@ -315,7 +322,7 @@ typedef struct {
 /**
    @brief Evaluate a given parameter set for the Raman fit
    @param aData     Data forwarded from the fit algorithm call (structure
-                    containing the pixtables)
+                    containing the pixel tables)
    @param aPar      Current fit parameter.
    @param aRetval   Return value vector.
    @return CPL_ERROR_NONE if everything went OK.
@@ -351,12 +358,12 @@ muse_raman_eval(void *aData, cpl_array *aPar, cpl_array* aRetval)
 
 /*----------------------------------------------------------------------------*/
 /**
-   @brief  Fit raman lines to an array of pixtables
-   @param  aPixtable array of MUSE_RAMAN_RANGES (2) pixtables
+   @brief  Fit raman lines to an array of pixel tables
+   @param  aPixtable array of MUSE_RAMAN_RANGES (2) pixel tables
    @return Array with fit values
 
    The fit uses a common spatial profile (two dimensional 2nd order
-   polynomial) for both pixtables. The spatial profile is returned in
+   polynomial) for both pixel tables. The spatial profile is returned in
    the first five values of the returned array:
 
     * 0 - x² coefficient
@@ -366,9 +373,9 @@ muse_raman_eval(void *aData, cpl_array *aPar, cpl_array* aRetval)
     * 4 - y  coefficient
 
    The remaining two values of the array contain the central (x=y=0)
-   flux for both pixtables.
+   flux for both pixel tables.
 
-   This requires the pixtables to have an additional "lsf" column
+   This requires the pixel tables to have an additional "lsf" column
    containing the Line profile of the Raman scattering, normalized to
    one.
  */
