@@ -543,7 +543,14 @@ muse_sky_subtract_lines_old(muse_pixtable *aPixtable, cpl_table *aLines,
                n_slices);
   cpl_boolean debug = getenv("MUSE_DEBUG_SKY")
                     && atoi(getenv("MUSE_DEBUG_SKY")) > 0;
-  #pragma omp parallel for default(none)                 /* as req. by Ralf */ \
+
+  // FIXME: Removed default(none) clause here, to make the code work with
+  //        gcc9 while keeping older versions of gcc working too without
+  //        resorting to conditional compilation. Having default(none) here
+  //        causes gcc9 to abort the build because of __func__ not being
+  //        specified in a data sharing clause. Adding a data sharing clause
+  //        makes older gcc versions choke.
+  #pragma omp parallel for                                                     \
               shared(aLsfParams, aLines, debug, n_slices, slice_pixtable)
   for (i_slice = 0; i_slice < n_slices; i_slice++) {
     uint32_t origin
