@@ -54,7 +54,7 @@ double muse_trace_edgefinder(const cpl_vector *, double, double *, double *, cpl
 cpl_table *muse_trace(const muse_image *, int, double, int, cpl_table **);
 int muse_trace_table_get_order(const cpl_table *);
 cpl_polynomial **muse_trace_table_get_polys_for_slice(const cpl_table *, const unsigned short);
-void muse_trace_polys_delete(cpl_polynomial *[]);
+void muse_trace_polys_delete(cpl_polynomial **);
 
 cpl_error_code muse_trace_plot_samples(cpl_table *, cpl_table *, unsigned short, unsigned short, unsigned char, muse_image *);
 cpl_error_code muse_trace_plot_widths(cpl_table *, unsigned short, unsigned short, unsigned char);
