@@ -575,7 +575,7 @@ muse_wcs_locate_sources(muse_pixtable *aPixtable, float aSigma,
   /* fill existing empty header with the header of the *
    * cube, but without the third dimension in the WCS  */
   cpl_propertylist_copy_property_regexp(median->header, cube->header,
-                                        "^C...*3$|^CD3_.$", 1);
+                                        "^C...*3$|^CD3_.$|^SPECSYS$", 1);
   muse_imagelist_delete(list);
   if (!median) {
     return cpl_error_set_message(__func__, cpl_error_get_code(),
