@@ -185,7 +185,7 @@ muse_xcombine_weights_infotable(muse_pixtable **aPixtables)
   are stored in @em aStrehl and @em aStrehlErr.
 
   The function expects that the input list of pixel tables @em aPixtables is
-  @c NULL terminated. Processing of pixel tables stops at the first @NULL
+  @c NULL terminated. Processing of pixel tables stops at the first @c NULL
   element.
  */
 /*----------------------------------------------------------------------------*/
