@@ -71,10 +71,19 @@ muse_geometry_qc_spots(cpl_table *aSpots, cpl_propertylist *aHeader)
     cpl_table_duplicate_column(table, "fwhm", table, "xfwhm");
     cpl_table_add_columns(table, "fwhm", "yfwhm");
     cpl_table_multiply_scalar(table, "fwhm", 0.5);
+    cpl_errorstate es = cpl_errorstate_get();
     double mean = cpl_table_get_column_mean(table, "fwhm"),
            median = cpl_table_get_column_median(table, "fwhm"),
            stdev = cpl_table_get_column_stdev(table, "fwhm");
     cpl_table_delete(table);
+    if (!cpl_errorstate_is_equal(es)) {
+      cpl_errorstate_set(es);
+      cpl_msg_debug(__func__, "QC parameters for spots in exposure %u likely "
+                    "faulty", nexp);
+    } else {
+      /* only set mean value, if it's valid */
+      cpl_array_set_double(amean, nexp - nexp1, mean);
+    }
 
     char keyword[KEYWORD_LENGTH];
     snprintf(keyword, KEYWORD_LENGTH, QC_GEO_EXPk_MEAN, nexp);
@@ -83,8 +92,6 @@ muse_geometry_qc_spots(cpl_table *aSpots, cpl_propertylist *aHeader)
     cpl_propertylist_update_float(aHeader, keyword, median);
     snprintf(keyword, KEYWORD_LENGTH, QC_GEO_EXPk_STDEV, nexp);
     cpl_propertylist_update_float(aHeader, keyword, stdev);
-
-    cpl_array_set_double(amean, nexp - nexp1, mean);
   } /* for nexp */
   cpl_propertylist_update_float(aHeader, QC_GEO_FWHM_MEAN,
                                 cpl_array_get_mean(amean));
@@ -272,7 +279,14 @@ muse_geometry_reconstruct_combined(muse_processing *aProcessing,
 
   muse_pixtable **pts = cpl_calloc(kMuseNumIFUs, sizeof(muse_pixtable));
   unsigned char nifu;
-  #pragma omp parallel for default(none)                 /* as req. by Ralf */ \
+
+  // FIXME: Removed default(none) clause here, to make the code work with
+  //        gcc9 while keeping older versions of gcc working too without
+  //        resorting to conditional compilation. Having default(none) here
+  //        causes gcc9 to abort the build because of __func__ not being
+  //        specified in a data sharing clause. Adding a data sharing clause
+  //        makes older gcc versions choke.
+  #pragma omp parallel for                                                     \
           shared(gt, aParams, aProcessing, pts, skip)
   for (nifu = (unsigned)aParams->ifu1; nifu <= (unsigned)aParams->ifu2; nifu++) {
     cpl_table *trace = muse_processing_load_ctable(aProcessing, MUSE_TAG_TRACE_TABLE, nifu),
@@ -426,7 +440,14 @@ muse_geometry_reconstruct(muse_processing *aProcessing,
                  "wavelength range %.2f..%.2f", iframe + 1, fn, aLMin, aLMax);
     muse_pixtable **pts = cpl_calloc(kMuseNumIFUs, sizeof(muse_pixtable));
     unsigned char nifu;
-    #pragma omp parallel for default(none)               /* as req. by Ralf */ \
+
+    // FIXME: Removed default(none) clause here, to make the code work with
+    //        gcc9 while keeping older versions of gcc working too without
+    //        resorting to conditional compilation. Having default(none) here
+    //        causes gcc9 to abort the build because of __func__ not being
+    //        specified in a data sharing clause. Adding a data sharing clause
+    //        makes older gcc versions choke.
+    #pragma omp parallel for                                                   \
             shared(aParams, aProcessing, fn, frames, gt, pts)
     for (nifu = (unsigned)aParams->ifu1; nifu <= (unsigned)aParams->ifu2; nifu++) {
       cpl_table *trace = muse_processing_load_ctable(aProcessing, MUSE_TAG_TRACE_TABLE, nifu),
@@ -604,7 +625,14 @@ muse_geometry_compute(muse_processing *aProcessing,
   cpl_propertylist *headfinal = NULL;
   cpl_array *dy = cpl_array_new(0, CPL_TYPE_DOUBLE);
   unsigned int nifu;
-  #pragma omp parallel for default(none)                 /* as req. by Ralf */ \
+
+  // FIXME: Removed default(none) clause here, to make the code work with
+  //        gcc9 while keeping older versions of gcc working too without
+  //        resorting to conditional compilation. Having default(none) here
+  //        causes gcc9 to abort the build because of __func__ not being
+  //        specified in a data sharing clause. Adding a data sharing clause
+  //        makes older gcc versions choke.
+  #pragma omp parallel for                                                     \
           shared(aParams, aProcessing, centroid, dy, headfinal, mspots, rc,    \
                  trace, vlines, wavecal)
   for (nifu = (unsigned)aParams->ifu1; nifu <= (unsigned)aParams->ifu2; nifu++) {
@@ -710,7 +738,14 @@ muse_geometry_compute(muse_processing *aProcessing,
   /* variables for combined output tables */
   cpl_table *spots = NULL;
   muse_geo_table *geotable = NULL;
-  #pragma omp parallel for default(none)                 /* as req. by Ralf */ \
+
+  // FIXME: Removed default(none) clause here, to make the code work with
+  //        gcc9 while keeping older versions of gcc working too without
+  //        resorting to conditional compilation. Having default(none) here
+  //        causes gcc9 to abort the build because of __func__ not being
+  //        specified in a data sharing clause. Adding a data sharing clause
+  //        makes older gcc versions choke.
+  #pragma omp parallel for                                                     \
           shared(aParams, geotable, headfinal, mspots, spots, trace, vlines)
   for (nifu = (unsigned)aParams->ifu1; nifu <= (unsigned)aParams->ifu2; nifu++) {
     /* finally compute the geometry, initial and horizontal parts for one IFU */
