@@ -197,11 +197,11 @@ muse_standard_compute(muse_processing *aProcessing,
     char *objorig = cpl_strdup(cpl_propertylist_get_string(header, "OBJECT"));
     char *object = cpl_sprintf("Response curve (%s)", objorig);
     cpl_propertylist_update_string(header, "OBJECT", object);
-    cpl_error_code rc = rc = muse_processing_save_table(aProcessing, -1,
-                                                        fluxobjs[i]->response,
-                                                        header,
-                                                        MUSE_TAG_STD_RESPONSE,
-                                                        MUSE_TABLE_TYPE_MUSE);
+    cpl_error_code rc = muse_processing_save_table(aProcessing, -1,
+                                                   fluxobjs[i]->response,
+                                                   header,
+                                                   MUSE_TAG_STD_RESPONSE,
+                                                   MUSE_TABLE_TYPE_MUSE);
     cpl_free(object);
     if (rc != CPL_ERROR_NONE) {
       cpl_free(objorig);
