@@ -85,7 +85,6 @@ def cycle_marker_properties(index, colors, symbols):
     return (symbol, color)
 
 
-
 class WorldCoordinateSystem(object):
     def __init__(self, fits_datacontainer, fits_dataset=0, tiny=1.e-6):
         self.tiny = tiny
@@ -97,12 +96,14 @@ class WorldCoordinateSystem(object):
         self.cd_matrix = None
 
         try:
-            _equinox = get_inherited_key(fits_datacontainer, fits_dataset, "EQUINOX")
+            _equinox = get_inherited_key(
+                fits_datacontainer, fits_dataset, "EQUINOX")
         except KeyError:
             _equinox = None
 
         try:
-            _radecsys = get_inherited_key(fits_datacontainer, fits_dataset, "RADESYS")
+            _radecsys = get_inherited_key(
+                fits_datacontainer, fits_dataset, "RADESYS")
         except KeyError:
             try:
                 _radecsys = fits_datacontainer.all_hdu[fits_dataset].header["RADECSYS"]
@@ -204,10 +205,10 @@ class WorldCoordinateSystem(object):
             self.cd_matrix = None
             self.pc_matrix = None
 
-
     def image_to_celestial(self, xpix, ypix):
         # Linear transformation
-        pos = np.array([xpix - self.crpix[0], ypix - self.crpix[1]]).transpose()
+        pos = np.array([xpix - self.crpix[0], ypix -
+                        self.crpix[1]]).transpose()
         xpos, ypos = np.dot(self.cd_matrix, pos)
 
         # Gnomonic projection
@@ -231,7 +232,6 @@ class WorldCoordinateSystem(object):
 
         return (np.degrees(ra_rad), np.degrees(dec_rad))
 
-
     def celestial_to_image(self, ra_deg, dec_deg):
         ra_rad = np.radians(ra_deg)
         dec_rad = np.radians(dec_deg)
@@ -256,13 +256,14 @@ class WorldCoordinateSystem(object):
 
         invdet = 1. / np.linalg.det(self.cd_matrix)
 
-        xpix = (self.cd_matrix[1, 1] * xpos - self.cd_matrix[0, 1] * ypos) * invdet + self.crpix[0]
-        ypix = (self.cd_matrix[0, 0] * ypos - self.cd_matrix[1, 0] * xpos) * invdet + self.crpix[1]
+        xpix = (self.cd_matrix[1, 1] * xpos -
+                self.cd_matrix[0, 1] * ypos) * invdet + self.crpix[0]
+        ypix = (self.cd_matrix[0, 0] * ypos -
+                self.cd_matrix[1, 0] * xpos) * invdet + self.crpix[1]
 
         return (xpix, ypix)
 
 
-
 class DataPlotterManager(object):
 
     recipeName = "muse_exp_align"
@@ -270,7 +271,8 @@ class DataPlotterManager(object):
     tagFovPreview = "PREVIEW_FOV"
     tagAuxiliaryData = "SOURCE_LIST"
 
-    _src_list_column_ids = ["Id", "X", "Y", "RA", "DEC", "RA_CORR", "DEC_CORR", "Flux"]
+    _src_list_column_ids = ["Id", "X", "Y", "RA",
+                            "DEC", "RA_CORR", "DEC_CORR", "Flux"]
 
     _btn_label_all = "All detections (uncorrected)"
     _btn_label_all_corr = "All detections (corrected)"
@@ -297,15 +299,12 @@ class DataPlotterManager(object):
         super(DataPlotterManager, self).__init__()
         return
 
-
     def setWindowTitle(self):
         return self.recipeName + " GUI"
 
-
     def setWindowHelp(self):
         return "Help for " + self.setWindowTitle()
 
-
     def setInteractiveParameters(self):
         self.parameters += [
             reflex.RecipeParameter(
@@ -368,15 +367,13 @@ class DataPlotterManager(object):
                 displayName="srcmax",
                 group="Source Detection",
                 description="Maximum number of sources")
-            ]
+        ]
         return self.parameters
 
-
     def setCurrentParameterHelper(self, parameter_value_getter):
         self._get_parameter_value = parameter_value_getter
         return
 
-
     def readFitsData(self, fitsfiles):
         self.frameset = dict()
         for fitsfile in fitsfiles:
@@ -388,7 +385,8 @@ class DataPlotterManager(object):
             frame_id = os.path.basename(datasets.fits_file.name)
             if fitsfile.category == self.tagInputData:
                 frame_id += "\n(" + DataPlotterManager._obs_id + ": "
-                frame_id += datasets.readKeyword(DataPlotterManager._obs_id) + ")"
+                frame_id += datasets.readKeyword(
+                    DataPlotterManager._obs_id) + ")"
 
             frame = dict()
             frame["label"] = frame_id
@@ -403,14 +401,12 @@ class DataPlotterManager(object):
             self._plt_plotter = self._dummy_plot_draw
         return
 
-
     def addSubplots(self, figure):
         self._figure = figure
         self._figure.clear()
         self._plt_creator()
         return
 
-
     def plotWidgets(self):
 
         if "dummy" not in self._plt:
@@ -440,12 +436,10 @@ class DataPlotterManager(object):
 
         return widgets
 
-
     def plotProductsGraphics(self):
         self._plt_plotter()
         return
 
-
     # Event handler
 
     def on_image_selected(self, button_label):
@@ -470,7 +464,6 @@ class DataPlotterManager(object):
 
         return
 
-
     def on_resize(self, event):
         if hasattr(self, '_widgets') and "buttons" in self._widgets:
             bbox = self._plt["buttons"].get_position().get_points()
@@ -491,13 +484,13 @@ class DataPlotterManager(object):
                 circle.height = width * vscale
         return
 
-
     # Implementation of the plot creator and plotter delegates to be used
     # if the required data is actually available.
 
     def _data_plot_create(self):
         self._plt["buttons"] = self._figure.add_axes([0.05, 0.05, 0.35, 0.90])
-        self._plt["imageview"] = self._figure.add_axes([0.55, 0.05, 0.40, 0.90])
+        self._plt["imageview"] = self._figure.add_axes(
+            [0.55, 0.05, 0.40, 0.90])
 
         # Turn off coordinate display in the status bar for the radio
         # buttons widget
@@ -505,7 +498,6 @@ class DataPlotterManager(object):
 
         return
 
-
     def _data_plot_draw(self):
         if self._image_selector_active >= 0:
             img_frame = self.frameset[self.tagInputData][self._image_selector_active]
@@ -523,7 +515,8 @@ class DataPlotterManager(object):
             tbl_data = None
             num_sources = 0
             for frame in self.frameset[self.tagAuxiliaryData]:
-                timestamp = frame["datasets"].readKeyword(DataPlotterManager._obs_id)
+                timestamp = frame["datasets"].readKeyword(
+                    DataPlotterManager._obs_id)
                 if timestamp == img_data.readKeyword(DataPlotterManager._obs_id):
                     print("Reading Source list '" + frame["label"] +
                           "' for FOV image '" + img_data.fits_file.name + "'")
@@ -536,10 +529,6 @@ class DataPlotterManager(object):
 
             xlabel = "X [pixel]"
             ylabel = "Y [pixel]"
-            xpos = tbl_data["X"]
-            ypos = tbl_data["Y"]
-            marker_size = np.zeros(len(tbl_data["Id"]))
-            marker_size[:] = 8
 
             self._plt["imageview"].clear()
 
@@ -551,7 +540,8 @@ class DataPlotterManager(object):
             imageview.setXLinearWCSAxis(0., 1., 1.)
             imageview.setYLinearWCSAxis(0., 1., 1.)
 
-            imageview.display(self._plt["imageview"], "Exposure FOV", tooltip, img_data.image)
+            imageview.display(self._plt["imageview"],
+                              "Exposure FOV", tooltip, img_data.image)
 
             # This must be called after imageview display, to override the internal
             # formatting by imageview.display. This is a hack!
@@ -559,24 +549,33 @@ class DataPlotterManager(object):
             self._plt["imageview"].format_coord = types.MethodType(format_coordinates,
                                                                    (img_data, wcs))
 
-            marker, color = cycle_marker_properties(self._image_selector_active,
-                                                    DataPlotterManager._marker_colors,
-                                                    DataPlotterManager._marker_symbols)
-
             self._plt["imageview"].autoscale(enable=False, tight=True)
-            self._plt["imageview"].scatter(xpos, ypos,
-                                           facecolors="none", edgecolors=color,
-                                           marker=marker, s=marker_size**2)
 
-            for idx, src_id in enumerate(tbl_data["Id"]):
-                txt_offset = 0.5 * np.sqrt(2.) * marker_size[idx]
-                xydata = (xpos[idx], ypos[idx])
-                xytext = (txt_offset, -txt_offset)
-                self._plt["imageview"].annotate(str(src_id),
-                                                xy=xydata, xycoords="data",
-                                                xytext=xytext, textcoords="offset points",
-                                                ha="left", va="top", fontsize="x-small",
-                                                color=color, clip_on=True)
+            # If the source table is not empty, plot the detected source
+            # positions and their labels on top of the displayed image
+            if num_sources > 0:
+                xpos = tbl_data["X"]
+                ypos = tbl_data["Y"]
+                marker_size = np.zeros(num_sources)
+                marker_size[:] = 8
+
+                marker, color = cycle_marker_properties(self._image_selector_active,
+                                                        DataPlotterManager._marker_colors,
+                                                        DataPlotterManager._marker_symbols)
+
+                self._plt["imageview"].scatter(xpos, ypos,
+                                               facecolors="none", edgecolors=color,
+                                               marker=marker, s=marker_size**2)
+
+                for idx, src_id in enumerate(tbl_data["Id"]):
+                    txt_offset = 0.5 * np.sqrt(2.) * marker_size[idx]
+                    xydata = (xpos[idx], ypos[idx])
+                    xytext = (txt_offset, -txt_offset)
+                    self._plt["imageview"].annotate(str(src_id),
+                                                    xy=xydata, xycoords="data",
+                                                    xytext=xytext, textcoords="offset points",
+                                                    ha="left", va="top", fontsize="x-small",
+                                                    color=color, clip_on=True)
         else:
             # If it exists, use the FOV preview image to setup the image
             # display and get the WCS. If the preview image is not available
@@ -592,7 +591,8 @@ class DataPlotterManager(object):
 
             # Show the FOV preview as background image only if the selected
             # overlay are the corrected source positions.
-            show_bkg_image = have_fov_preview and self._image_selector_active in [-2]
+            show_bkg_image = have_fov_preview and \
+                self._image_selector_active in [-2]
 
             wcs = WorldCoordinateSystem(img_data, 1)
             if wcs.ctype[0].strip() != "RA---TAN" or wcs.ctype[1].strip() != "DEC--TAN":
@@ -609,7 +609,8 @@ class DataPlotterManager(object):
 
             src_lists = list()
             for img_frame in self.frameset[self.tagInputData]:
-                timestamp = img_frame["datasets"].readKeyword(DataPlotterManager._obs_id)
+                timestamp = img_frame["datasets"].readKeyword(
+                    DataPlotterManager._obs_id)
                 img_name = img_frame["datasets"].fits_file.name
                 for tbl_frame in self.frameset[self.tagAuxiliaryData]:
                     if timestamp == tbl_frame["datasets"].readKeyword(DataPlotterManager._obs_id):
@@ -644,7 +645,8 @@ class DataPlotterManager(object):
             imageview.setLabels(xlabel, ylabel)
             imageview.setXLinearWCSAxis(0., 1., 1.)
             imageview.setYLinearWCSAxis(0., 1., 1.)
-            imageview.display(self._plt["imageview"], "Source Positions", tooltip, bkg_image)
+            imageview.display(self._plt["imageview"],
+                              "Source Positions", tooltip, bkg_image)
 
             # This must be called after imageview display, to override the internal
             # formatting by imageview.display. This is a hack!
@@ -655,23 +657,25 @@ class DataPlotterManager(object):
             self._plt["imageview"].autoscale(enable=False)
 
             for idx, src_list in enumerate(src_lists):
-                img_coordinates = np.empty((len(src_list[col_name_x]), 2))
-                sky_coordinates = zip(src_list[col_name_x], src_list[col_name_y])
-                for i, (ra_deg, dec_deg) in enumerate(sky_coordinates):
-                    img_coordinates[i] = wcs.celestial_to_image(ra_deg, dec_deg)
-                marker_size = np.zeros(len(tbl_data["Id"]))
-                marker_size[:] = 8
-                marker, color = cycle_marker_properties(idx,
-                                                        DataPlotterManager._marker_colors,
-                                                        DataPlotterManager._marker_symbols)
-                self._plt["imageview"].scatter(img_coordinates[:, 0], img_coordinates[:, 1],
-                                               facecolors="none", edgecolors=color,
-                                               marker=marker, s=marker_size**2)
-
+                num_sources = len(src_list[col_name_x])
+                if num_sources > 0:
+                    img_coordinates = np.empty((num_sources, 2))
+                    sky_coordinates = zip(
+                        src_list[col_name_x], src_list[col_name_y])
+                    for i, (ra_deg, dec_deg) in enumerate(sky_coordinates):
+                        img_coordinates[i] = wcs.celestial_to_image(
+                            ra_deg, dec_deg)
+                    marker_size = np.zeros(num_sources)
+                    marker_size[:] = 8
+                    marker, color = cycle_marker_properties(idx,
+                                                            DataPlotterManager._marker_colors,
+                                                            DataPlotterManager._marker_symbols)
+                    self._plt["imageview"].scatter(img_coordinates[:, 0], img_coordinates[:, 1],
+                                                   facecolors="none", edgecolors=color,
+                                                   marker=marker, s=marker_size**2)
 
         return
 
-
     # Implementation of the dummy plot creator and plotter delegates
     # follows here.
 
@@ -679,7 +683,6 @@ class DataPlotterManager(object):
         self._plt["dummy"] = self._figure.add_subplot(1, 1, 1)
         return
 
-
     def _dummy_plot_draw(self):
         label = "Data not found!\n\nInput files should contain these types:\n%s\n%s" \
             % (self.tagInputData, self.tagAuxiliaryData)
@@ -692,12 +695,10 @@ class DataPlotterManager(object):
         return
 
 
-
 if __name__ == "__main__":
 
     from reflex_interactive_app import PipelineInteractiveApp
 
-
     interactive_app = PipelineInteractiveApp(enable_init_sop=True)
     interactive_app.parse_args()
 
