@@ -50,7 +50,7 @@ int main(int argc, char **argv)
   cpl_propertylist_append_float(header, "RA", 292.242371); /* 19:28:58.1 RA (J2000) pointing */
   cpl_propertylist_append_float(header, "DEC", -41.57659); /* -41:34:35.7  DEC (J2000) pointing */
   cpl_propertylist_append_float(header, "EQUINOX", 2000.); /* Standard FK5 (years) */
-  cpl_propertylist_append_string(header, "RADECSYS", "FK5 " ); /* Coordinate reference frame */
+  cpl_propertylist_append_string(header, "RADESYS", "FK5 " ); /* Coordinate reference frame */
   cpl_propertylist_append_float(header, "LST", 63552.4); /* 17:39:12.400 LST at start */
   cpl_propertylist_append_float(header, "UTC", 1264.); /* 00:21:04.000 UT at start */
   cpl_propertylist_append_float(header, "EXPTIME", 900.); /* Integration time (s) */
@@ -605,7 +605,7 @@ int main(int argc, char **argv)
   cpl_propertylist_insert_string(header, "RA", "TELESCOP", "ESO-VLT-U4"); // ESO <TEL>
   cpl_propertylist_insert_string(header, "TELESCOP", "INSTRUME", "MUSE"); // Instrument used.
   cpl_propertylist_insert_string(header, "INSTRUME", "OBJECT", "ESO338-IG0"); // Original target.
-  cpl_propertylist_insert_string(header, "EXPTIME", "RADECSYS", "FK5"); // Coordinate system
+  cpl_propertylist_insert_string(header, "EXPTIME", "RADESYS", "FK5"); // Coordinate system
   cpl_propertylist_insert_string(header, "LST", "DATE-OBS", "2014-06-25T04:01:58.616"); // Observing date
   cpl_propertylist_insert_double(header, "LST", "UTC", 14509.000); // [s] 04:01:48.000 UTC
   cpl_propertylist_append_double(header, "ESO TEL GEOELEV", 2648.0); // [m] Elevation above sea level
@@ -639,7 +639,7 @@ int main(int argc, char **argv)
   cpl_propertylist_append_double(header, "RA", 291.993241); // [deg] 19:27:58.3 RA (J2000) pointing
   cpl_propertylist_append_double(header, "DEC", -41.57611); // [deg] -41:34:34.0 DEC (J2000) pointing
   cpl_propertylist_append_double(header, "EQUINOX", 2000.0); // Standard FK5
-  cpl_propertylist_append_string(header, "RADECSYS", "FK5"); // Coordinate system
+  cpl_propertylist_append_string(header, "RADESYS", "FK5"); // Coordinate system
   cpl_propertylist_append_double(header, "EXPTIME", 750.0000000); // Integration time
   cpl_propertylist_append_double(header, "MJD-OBS", 56833.23799131); // Obs start
   cpl_propertylist_append_string(header, "DATE-OBS", "2014-06-25T05:42:42.449"); // Observing date
@@ -674,7 +674,7 @@ int main(int argc, char **argv)
   cpl_propertylist_append_double(header, "RA", 291.992792); // [deg] 19:27:58.2 RA (J2000) pointing
   cpl_propertylist_append_double(header, "DEC", -41.57449); // [deg] -41:34:28.1 DEC (J2000) pointing
   cpl_propertylist_append_double(header, "EQUINOX", 2000.0); // Standard FK5
-  cpl_propertylist_append_string(header, "RADECSYS", "FK5"); // Coordinate system
+  cpl_propertylist_append_string(header, "RADESYS", "FK5"); // Coordinate system
   cpl_propertylist_append_double(header, "EXPTIME", 900.0000000); // Integration time
   cpl_propertylist_append_double(header, "MJD-OBS", 56868.14878751); // Obs start
   cpl_propertylist_append_string(header, "DATE-OBS", "2014-07-30T03:34:15.240"); // Observing date
@@ -709,7 +709,7 @@ int main(int argc, char **argv)
   cpl_propertylist_append_double(header, "RA", 291.992791); // [deg] 19:27:58.2 RA (J2000) pointing
   cpl_propertylist_append_double(header, "DEC", -41.57483); // [deg] -41:34:29.3 DEC (J2000) pointing
   cpl_propertylist_append_double(header, "EQUINOX", 2000.0); // Standard FK5
-  cpl_propertylist_append_string(header, "RADECSYS", "FK5"); // Coordinate system
+  cpl_propertylist_append_string(header, "RADESYS", "FK5"); // Coordinate system
   cpl_propertylist_append_double(header, "EXPTIME", 900.0000000); // Integration time
   cpl_propertylist_append_double(header, "MJD-OBS", 56872.09891026); // Obs start
   cpl_propertylist_append_string(header, "DATE-OBS", "2014-08-03T02:22:25.846"); // Observing date
