@@ -194,7 +194,8 @@ muse_test_processing_frames_sort_test(const char *aDir, cpl_recipe *aRecipe)
     char date[24]; /* full UTC in ISO format plus ms and null byte */
     strftime(date, 20, "%FT%T", gmtime(&tv.tv_sec));
     /* write milliseconds to the same string, starting at the null byte */
-    snprintf(date+19, 5, ".%03ld", tv.tv_usec/1000);
+    int nms = snprintf(date+19, 5, ".%03ld", tv.tv_usec/1000);
+    cpl_test_eq(nms, 4);
 
     cpl_msg_debug(__func__, "exposure %d: date=\"%s\"", n, date);
     cpl_propertylist_append_string(header, "DATE-OBS", date);
