@@ -96,7 +96,7 @@ int main(int argc, char **argv)
   cpl_propertylist_append_double(pt1->header, "RA", 291.993241); // [deg] 19:27:58.3 RA (J2000) pointing
   cpl_propertylist_append_double(pt1->header, "DEC", -41.57611); // [deg] -41:34:34.0 DEC (J2000) pointing
   cpl_propertylist_append_double(pt1->header, "EQUINOX", 2000.0); // Standard FK5
-  cpl_propertylist_append_string(pt1->header, "RADECSYS", "FK5"); // Coordinate system
+  cpl_propertylist_append_string(pt1->header, "RADESYS", "FK5"); // Coordinate system
   cpl_propertylist_append_double(pt1->header, "EXPTIME", 750.0000000); // Integration time
   cpl_propertylist_append_double(pt1->header, "MJD-OBS", 56833.23799131); // Obs start
   cpl_propertylist_append_string(pt1->header, "DATE-OBS", "2014-06-25T05:42:42.449"); // Observing date
@@ -110,7 +110,7 @@ int main(int argc, char **argv)
   cpl_propertylist_append_double(pt2->header, "RA", 291.992791); // [deg] 19:27:58.2 RA (J2000) pointing
   cpl_propertylist_append_double(pt2->header, "DEC", -41.57483); // [deg] -41:34:29.3 DEC (J2000) pointing
   cpl_propertylist_append_double(pt2->header, "EQUINOX", 2000.0); // Standard FK5
-  cpl_propertylist_append_string(pt2->header, "RADECSYS", "FK5"); // Coordinate system
+  cpl_propertylist_append_string(pt2->header, "RADESYS", "FK5"); // Coordinate system
   cpl_propertylist_append_double(pt2->header, "EXPTIME", 900.0000000); // Integration time
   cpl_propertylist_append_double(pt2->header, "MJD-OBS", 56872.09891026); // Obs start
   cpl_propertylist_append_string(pt2->header, "DATE-OBS", "2014-08-03T02:22:25.846"); // Observing date
