@@ -19,6 +19,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+#define _DEFAULT_SOURCE
 #define _BSD_SOURCE /* get mkdtemp() from stdlib.h */
 #include <stdlib.h>
 #include <unistd.h> /* for chdir() */
@@ -29,12 +30,53 @@
 
 #define DIR_TEMPLATE "/tmp/muse_utils_test_XXXXXX"
 
+/* Compute mean of the data and standard-deviation of the slope over three *
+ * small wavelength ranges. Using the slope instead of the direct stddev   *
+ * should make this robust against the overall slope of the response or    *
+ * flat-field curve.                                                       */
+double *
+muse_test_utils_table_stats(muse_table *aSpec)
+{
+  cpl_table *tin = aSpec->table;
+  const char *colname = cpl_table_has_column(tin, "response") ? "response"
+                                                              : "data";
+  /* create column with slope, by shifting the data over 10 bins */
+  cpl_table_duplicate_column(tin, "slope", tin, colname);
+  cpl_table_shift_column(tin, "slope", 10);
+  cpl_table_subtract_columns(tin, "slope", colname);
+  double *stats = cpl_calloc(6, sizeof(double));
+  cpl_table_select_all(tin);
+  cpl_table_and_selected_double(tin, "lambda", CPL_GREATER_THAN, 4900.);
+  cpl_table_and_selected_double(tin, "lambda", CPL_LESS_THAN, 5100.);
+  cpl_table *tx = cpl_table_extract_selected(tin);
+  stats[0] = cpl_table_get_column_mean(tx, colname),
+  stats[1] = cpl_table_get_column_stdev(tx, "slope");
+  cpl_table_delete(tx);
+  cpl_table_select_all(tin);
+  cpl_table_and_selected_double(tin, "lambda", CPL_GREATER_THAN, 6400.);
+  cpl_table_and_selected_double(tin, "lambda", CPL_LESS_THAN, 6600.);
+  tx = cpl_table_extract_selected(tin);
+  stats[2] = cpl_table_get_column_mean(tx, colname),
+  stats[3] = cpl_table_get_column_stdev(tx, "slope");
+  cpl_table_delete(tx);
+  cpl_table_select_all(tin);
+  cpl_table_and_selected_double(tin, "lambda", CPL_GREATER_THAN, 7900.);
+  cpl_table_and_selected_double(tin, "lambda", CPL_LESS_THAN, 8100.);
+  tx = cpl_table_extract_selected(tin);
+  stats[4] = cpl_table_get_column_mean(tx, colname),
+  stats[5] = cpl_table_get_column_stdev(tx, "slope");
+  cpl_table_delete(tx);
+  cpl_table_erase_column(tin, "slope");
+  return stats;
+} /* muse_test_utils_table_stats() */
+
 typedef struct {
   const char *fn;
   const char *tag;
   cpl_frame_group group;
 } musefset;
 
+
 static cpl_frameset *
 muse_test_utils_new_frameset(musefset aSet[])
 {
@@ -139,6 +181,7 @@ muse_test_utils_compare_framesets(const cpl_frameset *aF1,
             called with the necessary data.
 
   This program explicitely tests
+    muse_utils_spectrum_smooth()
     muse_utils_frameset_merge_frames()   (but only for trivial cases!)
  */
 /*----------------------------------------------------------------------------*/
@@ -147,9 +190,123 @@ int main(int argc, char **argv)
   UNUSED_ARGUMENTS(argc, argv);
   cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_DEBUG);
 
-  /* Test trivial cases of muse_utils_frameset_merge_frames() */
+  /* Test muse_utils_spectrum_smooth() */
   cpl_errorstate ps = cpl_errorstate_get();
-  cpl_error_code rc = muse_utils_frameset_merge_frames(NULL, CPL_TRUE);
+  cpl_error_code rc;
+  /* try both response curves and flat-field spectra, *
+   * for WFM-NOAO-N and WFM-AO-E                      */
+  const char *tables[] = { "response_WFM-NOAO-N.fits",
+                           "response_WFM-AO-E.fits",
+                           "ffspec_WFM-AO-E.fits",
+                           "ffspec_WFM-NOAO-N.fits",
+                           NULL };
+  int i;
+  for (i = 0; tables[i] != NULL; i++) {
+    char *fn = cpl_sprintf("%s_%s", BASEFILENAME, tables[i]);
+    muse_table *spec = muse_table_load(fn, 0);
+    cpl_boolean hasresp = cpl_table_has_column(spec->table, "response");
+    cpl_msg_debug(__func__, "===== testing file \"%s\" === %s ===============",
+                  fn, hasresp ? "response curve" : "flat-field spectrum");
+    /* test effect of smoothing, but extracting a sub-table *
+     * and measuring mean and standard deviation            */
+    double *stats1 = muse_test_utils_table_stats(spec);
+    cpl_msg_debug("stats1", "%f +/- %f, %f +/- %f, %f +/- %f",
+                  stats1[0], stats1[1], stats1[2], stats1[3], stats1[4],
+                  stats1[5]);
+    rc = muse_utils_spectrum_smooth(spec, MUSE_SPECTRUM_SMOOTH_NONE);
+    cpl_test(rc == CPL_ERROR_NONE && cpl_errorstate_is_equal(ps));
+    double *stats2 = muse_test_utils_table_stats(spec);
+    cpl_msg_debug("stats2", "%f +/- %f, %f +/- %f, %f +/- %f",
+                  stats2[0], stats2[1], stats2[2], stats2[3], stats2[4],
+                  stats2[5]);
+    /* should all be equal to high precision */
+    cpl_test_eq(stats1[0], stats2[0]);
+    cpl_test_eq(stats1[1], stats2[1]);
+    cpl_test_eq(stats1[2], stats2[2]);
+    cpl_test_eq(stats1[3], stats2[3]);
+    cpl_test_eq(stats1[4], stats2[4]);
+    cpl_test_eq(stats1[5], stats2[5]);
+    cpl_free(stats2);
+
+    rc = muse_utils_spectrum_smooth(spec, MUSE_SPECTRUM_SMOOTH_MEDIAN);
+    cpl_test(rc == CPL_ERROR_NONE && cpl_errorstate_is_equal(ps));
+    double *stats3 = muse_test_utils_table_stats(spec);
+    cpl_msg_debug("stats3", "%f +/- %f, %f +/- %f, %f +/- %f",
+                  stats3[0], stats3[1], stats3[2], stats3[3], stats3[4],
+                  stats3[5]);
+    cpl_msg_debug("stats3", "means: %f %f %f, stdevs: %f %f %f",
+                  stats1[0] - stats3[0], stats1[2] - stats3[2],
+                  stats1[4] - stats3[4], stats1[1] - stats3[1],
+                  stats1[3] - stats3[3], stats1[5] - stats3[5]);
+    /* means should be almost the same, but stdev should now be smaller */
+    cpl_test(fabs(stats1[0] - stats3[0]) < 0.0016);
+    cpl_test(fabs(stats1[2] - stats3[2]) < 0.0016);
+    cpl_test(fabs(stats1[4] - stats3[4]) < 0.001);
+    if (hasresp) {
+      cpl_test(stats1[1] > stats3[1]);
+      cpl_test(stats1[3] > stats3[3]);
+      cpl_test(stats1[5] > stats3[5]);
+    } else { /* for flat-field spectra, the standard deviations *
+              * don't change through median smoothing           */
+      cpl_test_eq(stats1[1], stats3[1]);
+      cpl_test_eq(stats1[3], stats3[3]);
+      cpl_test_eq(stats1[5], stats3[5]);
+    }
+    cpl_free(stats3);
+    muse_table_delete(spec);
+
+    spec = muse_table_load(fn, 0);
+    ps = cpl_errorstate_get();
+    rc = muse_utils_spectrum_smooth(spec, MUSE_SPECTRUM_SMOOTH_PPOLY);
+#if 0
+    muse_table_save(spec, tables[i]);
+#endif
+    cpl_test(rc == CPL_ERROR_NONE && cpl_errorstate_is_equal(ps));
+    double *stats4 = muse_test_utils_table_stats(spec);
+    cpl_msg_debug("stats4", "%f +/- %f, %f +/- %f, %f +/- %f",
+                  stats4[0], stats4[1], stats4[2], stats4[3], stats4[4],
+                  stats4[5]);
+    cpl_msg_debug("stats4", "means: %f %f %f, stdevs: %f %f %f",
+                  stats1[0] - stats4[0], stats1[2] - stats4[2],
+                  stats1[4] - stats4[4], stats1[1] - stats4[1],
+                  stats1[3] - stats4[3], stats1[5] - stats4[5]);
+    cpl_test(fabs(stats1[0] - stats4[0]) < 0.0016);
+    cpl_test(stats1[1] > stats4[1]);
+    cpl_test(fabs(stats1[2] - stats4[2]) < 0.0026); /* a bit bigger to pass */
+    cpl_test(stats1[3] > stats4[3]);
+    cpl_test(fabs(stats1[4] - stats4[4]) < 0.001);
+    cpl_test(stats1[5] > stats4[5]);
+    cpl_free(stats1);
+    cpl_free(stats4);
+    if (i == 0) {
+      /* try with a broken table -> unsupported type */
+      cpl_table_erase_column(spec->table, "lambda");
+      ps = cpl_errorstate_get();
+      rc = muse_utils_spectrum_smooth(spec, MUSE_SPECTRUM_SMOOTH_PPOLY);
+      cpl_test(rc == CPL_ERROR_UNSUPPORTED_MODE && cpl_errorstate_is_equal(ps));
+      cpl_errorstate_set(ps);
+      /* also try with a response function without error column */
+      muse_table_delete(spec);
+      spec = muse_table_load(fn, 0);
+      cpl_table_erase_column(spec->table, "resperr");
+      ps = cpl_errorstate_get();
+      rc = muse_utils_spectrum_smooth(spec, MUSE_SPECTRUM_SMOOTH_PPOLY);
+      cpl_test(rc == CPL_ERROR_NONE && cpl_errorstate_is_equal(ps));
+      muse_table_delete(spec);
+      /* and the same but for median smoothing */
+      spec = muse_table_load(fn, 0);
+      cpl_table_erase_column(spec->table, "resperr");
+      ps = cpl_errorstate_get();
+      rc = muse_utils_spectrum_smooth(spec, MUSE_SPECTRUM_SMOOTH_MEDIAN);
+      cpl_test(rc == CPL_ERROR_NONE && cpl_errorstate_is_equal(ps));
+    } /* if i==0 */
+    muse_table_delete(spec);
+    cpl_free(fn);
+  } /* for i (all tables) */
+
+  /* Test trivial cases of muse_utils_frameset_merge_frames() */
+  ps = cpl_errorstate_get();
+  rc = muse_utils_frameset_merge_frames(NULL, CPL_TRUE);
   cpl_test(!cpl_errorstate_is_equal(ps) && rc == CPL_ERROR_NULL_INPUT);
   cpl_errorstate_set(ps);
   /* check with existing but empty frameset */
