@@ -19,6 +19,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #define _DEFAULT_SOURCE
 #define _BSD_SOURCE /* get setenv() from stdlib.h */
 #include <stdlib.h> /* setenv() */
@@ -38,6 +42,7 @@ muse_test_xcombine_pixtable_create(double aValue)
   cpl_propertylist_append_float(pt->header, "DEC", -1e-4 * aValue);
   cpl_propertylist_append_string(pt->header, "CTYPE1", "RA---TAN");
   cpl_propertylist_append_string(pt->header, "CTYPE2", "DEC--TAN");
+  cpl_propertylist_append_string(pt->header, "ESO INS MODE", "NFM-AO-N");
   pt->table = muse_cpltable_new(muse_pixtable_def, 10);
   cpl_table_fill_column_window(pt->table, MUSE_PIXTABLE_XPOS, 0, 10, 0.);
   cpl_table_fill_column_window(pt->table, MUSE_PIXTABLE_YPOS, 0, 10, 0.);
@@ -71,6 +76,7 @@ muse_test_xcombine_pixtable_create_pos(double aValue, double aRA, double aDEC)
   cpl_propertylist_append_string(pt->header, "CTYPE2", "DEC--TAN");
   cpl_propertylist_append_double(pt->header, "ESO INS DROT POSANG", 0.);
   cpl_propertylist_append_string(pt->header, "ESO INS DROT MODE", "SKY");
+  cpl_propertylist_append_string(pt->header, "ESO INS MODE", "NFM-AO-N");
   pt->table = muse_cpltable_new(muse_pixtable_def, 1);
   cpl_table_fill_column_window(pt->table, MUSE_PIXTABLE_XPOS, 0, 1, 0.);
   cpl_table_fill_column_window(pt->table, MUSE_PIXTABLE_YPOS, 0, 1, 0.);
@@ -102,6 +108,7 @@ muse_test_xcombine_pixtable_create_cosmos(int aExp)
     cpl_propertylist_append_string(pt->header, "DATE-OBS", "2015-04-15T00:04:51.493"); /* Observing date */
     cpl_propertylist_append_string(pt->header, "ESO INS DROT MODE", "SKY"); /* Instrument derotator mode */
     cpl_propertylist_append_double(pt->header, "ESO INS DROT POSANG", 0.5000); /* [deg] Derotator position angle */
+    cpl_propertylist_append_string(pt->header, "ESO INS MODE", "NFM-AO-N");
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX AVG", 0.774); /* [arcsec] AG FWHM X mean value */
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX MAX", 0.993); /* [arcsec] AG FWHM X maximum value */
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX MED", 0.764); /* [arcsec] AG FWHM X median value */
@@ -133,6 +140,7 @@ muse_test_xcombine_pixtable_create_cosmos(int aExp)
     cpl_propertylist_append_string(pt->header, "DATE-OBS", "2015-04-15T00:21:42.270"); /* Observing date */
     cpl_propertylist_append_string(pt->header, "ESO INS DROT MODE", "SKY"); /* Instrument derotator mode */
     cpl_propertylist_append_double(pt->header, "ESO INS DROT POSANG", 90.5000); /* [deg] Derotator position angle */
+    cpl_propertylist_append_string(pt->header, "ESO INS MODE", "NFM-AO-N");
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX AVG", 0.790); /* [arcsec] AG FWHM X mean value */
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX MAX", 0.920); /* [arcsec] AG FWHM X maximum value */
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX MED", 0.788); /* [arcsec] AG FWHM X median value */
@@ -164,6 +172,7 @@ muse_test_xcombine_pixtable_create_cosmos(int aExp)
     cpl_propertylist_append_string(pt->header, "DATE-OBS", "2015-04-15T00:38:33.470"); /* Observing date */
     cpl_propertylist_append_string(pt->header, "ESO INS DROT MODE", "SKY"); /* Instrument derotator mode */
     cpl_propertylist_append_double(pt->header, "ESO INS DROT POSANG", 180.5000); /* [deg] Derotator position angle */
+    cpl_propertylist_append_string(pt->header, "ESO INS MODE", "NFM-AO-N");
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX AVG", 0.825); /* [arcsec] AG FWHM X mean value */
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX MAX", 0.991); /* [arcsec] AG FWHM X maximum value */
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX MED", 0.829); /* [arcsec] AG FWHM X median value */
@@ -195,6 +204,7 @@ muse_test_xcombine_pixtable_create_cosmos(int aExp)
     cpl_propertylist_append_string(pt->header, "DATE-OBS", "2015-04-15T00:55:23.285"); /* Observing date */
     cpl_propertylist_append_string(pt->header, "ESO INS DROT MODE", "SKY"); /* Instrument derotator mode */
     cpl_propertylist_append_double(pt->header, "ESO INS DROT POSANG", 270.5000); /* [deg] Derotator position angle */
+    cpl_propertylist_append_string(pt->header, "ESO INS MODE", "NFM-AO-N");
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX AVG", 0.831); /* [arcsec] AG FWHM X mean value */
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX MAX", 1.045); /* [arcsec] AG FWHM X maximum value */
     cpl_propertylist_append_double(pt->header, "ESO OCS SGS AG FWHMX MED", 0.821); /* [arcsec] AG FWHM X median value */
@@ -681,6 +691,80 @@ int main(int argc, char **argv)
   muse_pixtable_delete(pt2);
   muse_pixtable_delete(pt3);
   muse_pixtable_delete(pt4);
+  pts[0] = NULL;
+  pts[1] = NULL;
+  pts[2] = NULL;
+  pts[3] = NULL;
+
+  /* test computation of the RTC Strehl ratio for the combined pixel table */
+  pts[0] = muse_test_xcombine_pixtable_create_cosmos(1);
+  pts[1] = muse_test_xcombine_pixtable_create_cosmos(2);
+  pts[2] = muse_test_xcombine_pixtable_create_cosmos(3);
+  cpl_propertylist_update_double(pts[0]->header, MUSE_HDR_RTC_STREHL, 1.);
+  cpl_propertylist_update_double(pts[0]->header, MUSE_HDR_RTC_STREHLERR, 0.25);
+  cpl_propertylist_update_double(pts[1]->header, MUSE_HDR_RTC_STREHL, 2.);
+  cpl_propertylist_update_double(pts[1]->header, MUSE_HDR_RTC_STREHLERR, 0.1);
+  cpl_propertylist_update_double(pts[2]->header, MUSE_HDR_RTC_STREHL, 3.);
+  cpl_propertylist_update_double(pts[2]->header, MUSE_HDR_RTC_STREHLERR, 0.5);
+  ptcomb = muse_xcombine_tables(pts, NULL);
+  cpl_test_nonnull(ptcomb);
+  cpl_test(cpl_propertylist_has(ptcomb->header, MUSE_HDR_RTC_STREHL) &&
+           cpl_propertylist_has(ptcomb->header, MUSE_HDR_RTC_STREHLERR));
+  /* check that the RTC Strehl keywords of the combined pixel table has *
+   * the correct values                                                */
+  cpl_test_abs(cpl_propertylist_get_double(ptcomb->header, MUSE_HDR_RTC_STREHL),
+               1.9, 100. * DBL_EPSILON);
+  cpl_test_abs(cpl_propertylist_get_double(ptcomb->header, MUSE_HDR_RTC_STREHLERR),
+               0.091287, 1.e-6);
+  muse_pixtable_delete(ptcomb);
+  ptcomb = NULL;
+  muse_pixtable_delete(pts[0]);
+  muse_pixtable_delete(pts[1]);
+  muse_pixtable_delete(pts[2]);
+  /* test behavior if not all pixel tables provide the RTC Strehl header keywords */
+  pts[0] = muse_test_xcombine_pixtable_create_cosmos(1);
+  pts[1] = muse_test_xcombine_pixtable_create_cosmos(2);
+  pts[2] = muse_test_xcombine_pixtable_create_cosmos(3);
+  cpl_propertylist_update_double(pts[0]->header, MUSE_HDR_RTC_STREHL, 1.);
+  cpl_propertylist_update_double(pts[0]->header, MUSE_HDR_RTC_STREHLERR, 0.25);
+  cpl_propertylist_update_double(pts[2]->header, MUSE_HDR_RTC_STREHL, 3.);
+  cpl_propertylist_update_double(pts[2]->header, MUSE_HDR_RTC_STREHLERR, 0.5);
+  ptcomb = muse_xcombine_tables(pts, NULL);
+  cpl_test_nonnull(ptcomb);
+  cpl_test(cpl_propertylist_has(ptcomb->header, MUSE_HDR_RTC_STREHL) &&
+           cpl_propertylist_has(ptcomb->header, MUSE_HDR_RTC_STREHLERR));
+  /* check that the RTC Strehl keywords are still correct */
+  cpl_test_abs(cpl_propertylist_get_double(ptcomb->header, MUSE_HDR_RTC_STREHL),
+               1.4, 100. * DBL_EPSILON);
+  cpl_test_abs(cpl_propertylist_get_double(ptcomb->header, MUSE_HDR_RTC_STREHLERR),
+               0.223607, 1.e-6);
+  muse_pixtable_delete(ptcomb);
+  ptcomb = NULL;
+  muse_pixtable_delete(pts[0]);
+  muse_pixtable_delete(pts[1]);
+  muse_pixtable_delete(pts[2]);
+  pts[0] = muse_test_xcombine_pixtable_create_cosmos(1);
+  pts[1] = muse_test_xcombine_pixtable_create_cosmos(2);
+  pts[2] = muse_test_xcombine_pixtable_create_cosmos(3);
+  cpl_propertylist_update_double(pts[2]->header, MUSE_HDR_RTC_STREHL, 3.);
+  cpl_propertylist_update_double(pts[2]->header, MUSE_HDR_RTC_STREHLERR, 0.5);
+  ptcomb = muse_xcombine_tables(pts, NULL);
+  cpl_test_nonnull(ptcomb);
+  cpl_test(cpl_propertylist_has(ptcomb->header, MUSE_HDR_RTC_STREHL) &&
+           cpl_propertylist_has(ptcomb->header, MUSE_HDR_RTC_STREHLERR));
+  /* check that the RTC Strehl keywords are still correct */
+  cpl_test_abs(cpl_propertylist_get_double(ptcomb->header, MUSE_HDR_RTC_STREHL),
+               3., 100. * DBL_EPSILON);
+  cpl_test_abs(cpl_propertylist_get_double(ptcomb->header, MUSE_HDR_RTC_STREHLERR),
+               0.5, 1.e-6);
+  muse_pixtable_delete(ptcomb);
+  ptcomb = NULL;
+  muse_pixtable_delete(pts[0]);
+  muse_pixtable_delete(pts[1]);
+  muse_pixtable_delete(pts[2]);
+  pts[0] = NULL;
+  pts[1] = NULL;
+  pts[2] = NULL;
 
   /* check muse_xcombine_find_offsets() separately */
   es = cpl_errorstate_get();
