@@ -176,8 +176,20 @@ int main(int argc, char **argv)
       cpl_table *table = cpl_table_load(iname, iext, 1);
       cpl_propertylist *hout = cpl_propertylist_duplicate(header);
       cpl_propertylist_append(hout, hext);
-      /* the original extensions don't have any header, not even EXTNAME */
-      cpl_table_save(table, hout, NULL, outfn, CPL_IO_CREATE);
+      if (strlen(extname) == 6) {
+        /* the original extensions don't have any header, not even EXTNAME */
+        cpl_table_save(table, hout, NULL, outfn, CPL_IO_CREATE);
+      } else {
+        cpl_propertylist *hextout = cpl_propertylist_new();
+        /* find the part after the dot and use that for the output EXTNAME */
+        char *extnew = strchr(extname, '.');
+        if (extnew) {
+          extnew += 1; /* go after the dot */
+          cpl_propertylist_append_string(hextout, "EXTNAME", extnew);
+        }
+        cpl_table_save(table, hout, hextout, outfn, CPL_IO_CREATE);
+        cpl_propertylist_delete(hextout);
+      }
       cpl_table_delete(table);
       cpl_propertylist_delete(hout);
       break;
